@@ -102,21 +102,6 @@ def process_prediction(
     chains = list(seq_dict.keys())
     delims = np.cumsum([len(s) for s in seq_dict.values()]).tolist()
 
-    if do_refine:
-        if use_openmm:
-            from igfold.refine.openmm_ref import refine
-        else:
-            try:
-                from igfold.refine.pyrosetta_ref import refine
-                refine_input = [pdb_file, pdb_string]
-            except ImportError as e:
-                print(
-                    "Warning: PyRosetta not available. Using OpenMM instead.")
-                print(e)
-                from igfold.refine.openmm_ref import refine
-                refine_input = [pdb_file]
-                use_openmm = True
-
     write_pdb = not do_refine or use_openmm
     pdb_string = save_PDB(
         pdb_file,
@@ -130,10 +115,27 @@ def process_prediction(
     )
 
     if do_refine:
+        if use_openmm:
+            try:
+                from igfold.refine.openmm_ref import refine
+                refine_input = [pdb_file]
+            except:
+                exit("OpenMM not installed. Please install OpenMM to use refinement.")
+        else:
+            try:
+                from igfold.refine.pyrosetta_ref import refine
+                refine_input = [pdb_file, pdb_string]
+            except:
+                exit("PyRosetta not installed. Please install PyRosetta to use refinement.")
+
         refine(*refine_input)
 
     if do_renum:
-        from igfold.utils.abnumber_ import renumber_pdb
+        try:
+            from igfold.utils.abnumber_ import renumber_pdb
+        except:
+            exit("AbNumber not installed. Please install AbNumber to use renumbering.")
+        
         renumber_pdb(
             pdb_file,
             pdb_file,
@@ -149,6 +151,7 @@ def process_prediction(
 
 
 def fold(
+    antiberty,
     models,
     pdb_file,
     fasta_file=None,
@@ -160,7 +163,6 @@ def fold(
     do_refine=True,
     use_openmm=False,
     do_renum=True,
-    save_decoys=False,
     truncate_sequences=False,
 ):
     seq_dict = get_sequence_dict(
@@ -169,7 +171,11 @@ def fold(
     )
 
     if truncate_sequences:
-        from igfold.utils.abnumber_ import truncate_seq
+        try:
+            from igfold.utils.abnumber_ import truncate_seq
+        except:
+            exit("AbNumber not installed. Please install AbNumber to use truncation.")
+
         seq_dict = {k: truncate_seq(v) for k, v in seq_dict.items()}
 
     if not exists(fasta_file):
@@ -181,6 +187,13 @@ def fold(
                     seq,
                 ))
 
+    embeddings, attentions = antiberty.embed(
+        seq_dict.values(),
+        return_attention=True,
+    )
+    embeddings = [e[1:-1].unsqueeze(0) for e in embeddings]
+    attentions = [a[:, :, 1:-1, 1:-1].unsqueeze(0) for a in attentions]
+
     temp_coords, temp_mask = process_template(
         template_pdb,
         fasta_file,
@@ -188,7 +201,8 @@ def fold(
         ignore_chain=ignore_chain,
     )
     model_in = IgFoldInput(
-        sequences=seq_dict.values(),
+        embeddings=embeddings,
+        attentions=attentions,
         template_coords=temp_coords,
         template_mask=temp_mask,
         return_embeddings=True,
@@ -198,18 +212,6 @@ def fold(
     with torch.no_grad():
         for i, model in enumerate(models):
             model_out = model(model_in)
-            if save_decoys:
-                decoy_pdb_file = os.path.splitext(
-                    pdb_file)[0] + f".decoy{i}.pdb"
-                process_prediction(
-                    model_out,
-                    decoy_pdb_file,
-                    fasta_file,
-                    do_refine=do_refine,
-                    use_openmm=use_openmm,
-                    do_renum=do_renum,
-                )
-
             model_out = model.gradient_refine(model_in, model_out)
             scores.append(model_out.prmsd.quantile(0.9))
             model_outs.append(model_out)
